@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import TypeAlias
 
 
 class ContentType(str, Enum):
@@ -16,3 +17,14 @@ class InsertWhere(str, Enum):
     LAST = "last"
     BEFORE = "before"
     AFTER = "after"
+
+
+YangData: TypeAlias = (
+    None | bool | int | float | str | list["YangData"] | dict[str, "YangData"]
+)
+
+
+class DryRunType(str, Enum):
+    CLI = "cli"
+    XML = "xml"
+    NATIVE = "NATIVE"
